==> apache-gluten-1.2.0-incubating-src.tar.gz: incubator-gluten-1.2.0/cpp-ch/local-engine/Parser/scalar_function_parser/fromUtcTimestamp.cpp <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <Parser/scalar_function_parser/utcTimestampTransform.h>

namespace local_engine
{

class FunctionParserFromUtcTimestamp : public FunctionParserUtcTimestampTransform
{
public:
    explicit FunctionParserFromUtcTimestamp(SerializedPlanParser * plan_parser_) : FunctionParserUtcTimestampTransform(plan_parser_) { }
    ~FunctionParserFromUtcTimestamp() = default;

    static constexpr auto name = "from_utc_timestamp";
    String getCHFunctionName(const substrait::Expression_ScalarFunction &) const override { return "from_utc_timestamp"; }
    String getName() const override { return "from_utc_timestamp"; }
};

static FunctionParserRegister<FunctionParserFromUtcTimestamp> fromUtcTimestamp;
}

==> apache-gluten-1.5.0-incubating-src.tar.gz: incubator-gluten-1.5.0/cpp-ch/local-engine/Parser/scalar_function_parser/fromUtcTimestamp.cpp <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <Parser/scalar_function_parser/utcTimestampTransform.h>

namespace local_engine
{

class FunctionParserFromUtcTimestamp : public FunctionParserUtcTimestampTransform
{
public:
    explicit FunctionParserFromUtcTimestamp(ParserContextPtr parser_context_) : FunctionParserUtcTimestampTransform(parser_context_) { }
    ~FunctionParserFromUtcTimestamp() override = default;

    static constexpr auto name = "from_utc_timestamp";
    String getCHFunctionName(const substrait::Expression_ScalarFunction &) const override { return "from_utc_timestamp"; }
    String getName() const override { return "from_utc_timestamp"; }
};

static FunctionParserRegister<FunctionParserFromUtcTimestamp> fromUtcTimestamp;
}
